#include "state.ih"

State::State()
:
    d_type(UNDETERMINED_),
    d_rule(-1)
{}
